:orphan:

Examples
========


.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Fill Line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_FillLine_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_FillLine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Fill Line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Simple Line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_Line_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_Line.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Simple Line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="STD line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_STDLine_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_STDLine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">STD line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Contour">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_contour_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_contour.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Contour</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="STD line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_ellipse_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_ellipse.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">STD line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Mesh - Line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_mesh_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_mesh.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Mesh - Line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Mesh - Matrix">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_mesh_2_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_mesh_2.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Mesh - Matrix</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Multi ax plots">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_multi_axes_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_multi_axes.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Multi ax plots</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="STD line">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_patch_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_patch.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">STD line</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Simple Line plus Scatter plot">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_scatter_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_scatter.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Simple Line plus Scatter plot</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3D Unstructured mesh">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_structured_mesh_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_structured_mesh.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">3D Unstructured mesh</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3D Unstructured mesh &amp; coloring">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_structured_mesh_coloring_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_structured_mesh_coloring.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">3D Unstructured mesh & coloring</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3D Unstructured mesh">

.. only:: html

  .. image:: /gallery/images/thumb/sphx_glr_plot_unstrictured_mesh_thumb.png
    :alt:

  :ref:`sphx_glr_gallery_plot_unstrictured_mesh.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">3D Unstructured mesh</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /gallery/plot_FillLine
   /gallery/plot_Line
   /gallery/plot_STDLine
   /gallery/plot_contour
   /gallery/plot_ellipse
   /gallery/plot_mesh
   /gallery/plot_mesh_2
   /gallery/plot_multi_axes
   /gallery/plot_patch
   /gallery/plot_scatter
   /gallery/plot_structured_mesh
   /gallery/plot_structured_mesh_coloring
   /gallery/plot_unstrictured_mesh



.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
